==> rattail_locsms-0.4.21.tar.gz: rattail_locsms-0.4.21/rattail_locsms/commands.py <==
# -*- coding: utf-8 -*-
################################################################################
#
#  Rattail -- Retail Software Framework
#  Copyright © 2010-2015 Lance Edgar
#
#  This file is part of Rattail.
#
#  Rattail is free software: you can redistribute it and/or modify it under the
#  terms of the GNU Affero General Public License as published by the Free
#  Software Foundation, either version 3 of the License, or (at your option)
#  any later version.
#
#  Rattail is distributed in the hope that it will be useful, but WITHOUT ANY
#  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
#  FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for
#  more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
#
################################################################################

"""
Rattail Commands
"""

from __future__ import unicode_literals
from __future__ import absolute_import

import os
import re
import sys
import shutil
import zipfile
import argparse
import logging

from rattail import commands


log = logging.getLogger(__name__)


class AdminCommand(commands.Subcommand):
    """
    Launches the 'SMS Admin' utility.  This tool is useful for administering
    SMS in both development and production environments.
    """

    name = 'sms-admin'
    description = "Launch 'SMS Admin' utility"

    def run(self, args):
        import wx
        from rattail_locsms.wx.Admin import AdminDialog

        app = wx.PySimpleApp()
        dlg = AdminDialog(None)
        dlg.ShowModal()
        dlg.Destroy()
        app.MainLoop()


class GenerateSampleCommand(commands.Subcommand):
    """
    Generates a zipped Sample (or Option) file to an SMS install folder; called
    as ``rattail sms-gen-sample``.
    """

    name = 'sms-gen-sample'
    description = "Generate zipped SMS Sample (or Option) file"

    def add_parser_args(self, parser):
        parser.add_argument('source_dir',
                            help=r"Path to Sample source code (e.g. C:\Samples\MySample)")
        parser.add_argument('target_dir',
                            help=r"Path to Samples folder (e.g. C:\Storeman\install\Samples)")
        parser.add_argument('-t', '--fix-timestamp', action='store_true',
                            help="Set timestamp according to source control log")
        parser.add_argument('-m', '--mako-args', nargs='*', metavar='VAR=VAL',
                            help="Render *.mako files with specified Mako context vars")

    def run(self, args):
        from rattail_locsms.samples import generate_sample

        mako_arg_pattern = re.compile(r'^([A-Za-z_]+)=(.*)$')

        mako_args = {}
        if args.mako_args:
            for elem in args.mako_args:
                m = mako_arg_pattern.match(elem)
                if not m:
                    sys.stderr.write("Invalid Mako argument: %s\n" % elem)
                    return
                mako_args[m.group(1)] = eval(m.group(2))

        generate_sample(self.config, args.source_dir, args.target_dir,
                        render_mako=bool(mako_args),
                        use_source_time=args.fix_timestamp,
                        **mako_args)


class ImportSmsData(commands.ImportSubcommand):
    """
    Import data from a LOC SMS database.
    """
    name = 'import-locsms'
    description = "Import data from a LOC SMS database."

    def import_data(self, args, session):
        from rattail_locsms.importing import import_from_locsms
        from rattail_locsms.db import configure_session_factory, Session as SmsSession

        configure_session_factory(self.config)
        sms_session = SmsSession()
        import_from_locsms(self.config, session, sms_session, models=args.models,
                           warnings=args.warnings, max_updates=args.max_updates,
                           progress=self.progress)
        sms_session.close()


class PullSampleCommand(commands.Subcommand):
    """
    "Pulls" an SMS Sample (or Option) zip file into a source repository's
    working directory; called as ``rattail sms-pull-sample``.

    This tool will unzip the sample (or option) file and copy the individual
    files contained within it to the local working directory (which is assumed
    to be associated with a source repository).
    """

    name = 'sms-pull-sample'
    description = "Pull zipped SMS Sample (or Option) file"

    def add_parser_args(self, parser):
        parser.add_argument('sample_file',
                            help=r"Path to zipped Sample (e.g. C:\Storeman\install\Samples\MySample.zip)")
        parser.add_argument('source_dir',
                            help=r"Path to source working directory (e.g. C:\Samples\MySample)")

    def run(self, args):
        from rattail_locsms.samples import absorb_sample
        absorb_sample(args.sample_file, args.source_dir)


class PurgeNonPAL(commands.Subcommand):
    """
    Generate SIL to purge records from SMS which have a target other than PAL.
    """
    name = 'sms-purge-non-pal'
    description = "Generate SIL to purge records with target other than PAL"
    model_choices = ['POS', 'Cost', 'Price']

    def add_parser_args(self, parser):
        parser.add_argument('--output-dir', '-O', default='.', metavar='DIR', type=os.path.abspath,
                            help="Path to output folder, in which SIL will be generated.")
        parser.add_argument('models', nargs='*', metavar='MODEL', type=self.arg_type_model,
                            help="One or more models to inspect.  If not specified, "
                            "then all supported models will be inspected.")

    def arg_type_model(self, string):
        if string not in self.model_choices:
            raise argparse.ArgumentTypeError(
                "{0} is invalid, must be one of: {1}".format(repr(string), self.model_choices))
        return string

    def run(self, args):
        from rattail_locsms import nonpal
        from rattail_locsms.db import Session
        from rattail_locsms.db import configure_session_factory

        configure_session_factory(self.config)
        models = args.models or self.model_choices
        session = Session()
        for model in models:
            purger = getattr(nonpal, '{0}Purger'.format(model))(self.config)
            offenders = purger.get_offenders(session)
            count = offenders.count()
            log.debug("found {0} offending {1} records".format(count, model))
            if count:
                path = purger.output_path(args.output_dir)
                log.debug("writing SIL to path: {0}".format(path))
                purger.generate_sil(offenders, path, progress=self.progress)
        session.close()

==> rattail_locsms-0.4.23.tar.gz: rattail_locsms-0.4.23/rattail_locsms/commands.py <==
# -*- coding: utf-8 -*-
################################################################################
#
#  Rattail -- Retail Software Framework
#  Copyright © 2010-2015 Lance Edgar
#
#  This file is part of Rattail.
#
#  Rattail is free software: you can redistribute it and/or modify it under the
#  terms of the GNU Affero General Public License as published by the Free
#  Software Foundation, either version 3 of the License, or (at your option)
#  any later version.
#
#  Rattail is distributed in the hope that it will be useful, but WITHOUT ANY
#  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
#  FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for
#  more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
#
################################################################################

"""
Rattail Commands
"""

from __future__ import unicode_literals
from __future__ import absolute_import

import os
import re
import sys
import shutil
import zipfile
import argparse
import logging

from rattail import commands


log = logging.getLogger(__name__)


class AdminCommand(commands.Subcommand):
    """
    Launches the 'SMS Admin' utility.  This tool is useful for administering
    SMS in both development and production environments.
    """

    name = 'sms-admin'
    description = "Launch 'SMS Admin' utility"

    def run(self, args):
        import wx
        from rattail_locsms.wx.Admin import AdminDialog

        app = wx.PySimpleApp()
        dlg = AdminDialog(None)
        dlg.ShowModal()
        dlg.Destroy()
        app.MainLoop()


class GenerateSampleCommand(commands.Subcommand):
    """
    Generates a zipped Sample (or Option) file to an SMS install folder; called
    as ``rattail sms-gen-sample``.
    """

    name = 'sms-gen-sample'
    description = "Generate zipped SMS Sample (or Option) file"

    def add_parser_args(self, parser):
        parser.add_argument('source_dir',
                            help=r"Path to Sample source code (e.g. C:\Samples\MySample)")
        parser.add_argument('target_dir',
                            help=r"Path to Samples folder (e.g. C:\Storeman\install\Samples)")
        parser.add_argument('-t', '--fix-timestamp', action='store_true',
                            help="Set timestamp according to source control log")
        parser.add_argument('-m', '--mako-args', nargs='*', metavar='VAR=VAL',
                            help="Render *.mako files with specified Mako context vars")

    def run(self, args):
        from rattail_locsms.samples import generate_sample

        mako_arg_pattern = re.compile(r'^([A-Za-z_]+)=(.*)$')

        mako_args = {}
        if args.mako_args:
            for elem in args.mako_args:
                m = mako_arg_pattern.match(elem)
                if not m:
                    sys.stderr.write("Invalid Mako argument: %s\n" % elem)
                    return
                mako_args[m.group(1)] = eval(m.group(2))

        generate_sample(self.config, args.source_dir, args.target_dir,
                        render_mako=bool(mako_args),
                        use_source_time=args.fix_timestamp,
                        **mako_args)


class ImportSmsData(commands.ImportSubcommand):
    """
    Import data from a LOC SMS database.
    """
    name = 'import-locsms'
    description = "Import data from a LOC SMS database."

    def get_handler_factory(self):
        from rattail_locsms.importing import LocSmsImportHandler
        return LocSmsImportHandler


class PullSampleCommand(commands.Subcommand):
    """
    "Pulls" an SMS Sample (or Option) zip file into a source repository's
    working directory; called as ``rattail sms-pull-sample``.

    This tool will unzip the sample (or option) file and copy the individual
    files contained within it to the local working directory (which is assumed
    to be associated with a source repository).
    """

    name = 'sms-pull-sample'
    description = "Pull zipped SMS Sample (or Option) file"

    def add_parser_args(self, parser):
        parser.add_argument('sample_file',
                            help=r"Path to zipped Sample (e.g. C:\Storeman\install\Samples\MySample.zip)")
        parser.add_argument('source_dir',
                            help=r"Path to source working directory (e.g. C:\Samples\MySample)")

    def run(self, args):
        from rattail_locsms.samples import absorb_sample
        absorb_sample(args.sample_file, args.source_dir)


class PurgeNonPAL(commands.Subcommand):
    """
    Generate SIL to purge records from SMS which have a target other than PAL.
    """
    name = 'sms-purge-non-pal'
    description = "Generate SIL to purge records with target other than PAL"
    model_choices = ['POS', 'Cost', 'Price']

    def add_parser_args(self, parser):
        parser.add_argument('--output-dir', '-O', default='.', metavar='DIR', type=os.path.abspath,
                            help="Path to output folder, in which SIL will be generated.")
        parser.add_argument('models', nargs='*', metavar='MODEL', type=self.arg_type_model,
                            help="One or more models to inspect.  If not specified, "
                            "then all supported models will be inspected.")

    def arg_type_model(self, string):
        if string not in self.model_choices:
            raise argparse.ArgumentTypeError(
                "{0} is invalid, must be one of: {1}".format(repr(string), self.model_choices))
        return string

    def run(self, args):
        from rattail_locsms import nonpal
        from rattail_locsms.db import Session

        models = args.models or self.model_choices
        session = Session()
        for model in models:
            purger = getattr(nonpal, '{0}Purger'.format(model))(self.config)
            offenders = purger.get_offenders(session)
            count = offenders.count()
            log.debug("found {0} offending {1} records".format(count, model))
            if count:
                path = purger.output_path(args.output_dir)
                log.debug("writing SIL to path: {0}".format(path))
                purger.generate_sil(offenders, path, progress=self.progress)
        session.close()
